pub struct TypeHeuristics;Expand description
Heuristics for guessing types when not found in values.yaml
These are patterns commonly seen in Helm charts that strongly suggest a particular type.
Implementations
Sourceimpl TypeHeuristics
impl TypeHeuristics
Sourcepub fn guess_type(path: &str) -> Option<InferredType>
pub fn guess_type(path: &str) -> Option<InferredType>
Guesses the type based on the path name using heuristics
Returns None if no heuristic matches.